Welcome to Colt's documentation!
================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   usage
   modules
   installation
   contributing
   authors
   history



.. colt_questions::

   a = 5
   [qm]
   b = 123
   
   c = mhm
   
   [selim]
   _key_hidden = 123

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
